Python bindings for netcon. You can find a mirror of the repository [here](https://github.com/TensorCon/netcon).

Follow all [install instructions](https://github.com/TensorCon/netcon/blob/mirror/README.md) for the netcon repository in order to utilize these bindings.